AGL_EXT(ARB_imaging,                   0)
AGL_EXT(ARB_multitexture,            1_2_1)
AGL_EXT(ARB_transpose_matrix,        1_3)
AGL_EXT(ARB_multisample,             1_3)
AGL_EXT(ARB_texture_env_add,         1_3)
AGL_EXT(ARB_texture_cube_map,        1_3)
AGL_EXT(ARB_texture_compression,     1_3)
AGL_EXT(ARB_texture_border_clamp,    1_3)
AGL_EXT(ARB_point_parameters,        1_4)
AGL_EXT(ARB_vertex_blend,              0)
AGL_EXT(ARB_texture_env_combine,     1_3)
AGL_EXT(ARB_texture_env_crossbar,    1_4)
AGL_EXT(ARB_texture_env_dot3,        1_3)
AGL_EXT(ARB_texture_mirrored_repeat, 1_4)
AGL_EXT(ARB_depth_texture,           1_4)
AGL_EXT(ARB_shadow,                  1_4)
AGL_EXT(ARB_shadow_ambient,            0)
AGL_EXT(ARB_window_pos,              1_4)
AGL_EXT(ARB_vertex_program,            0)
AGL_EXT(ARB_fragment_program,          0)
AGL_EXT(ARB_vertex_buffer_object,    1_5)
AGL_EXT(ARB_occlusion_query,         1_5)
AGL_EXT(ARB_shader_objects,            0) /* Those were promoted to Core in  */
AGL_EXT(ARB_vertex_shader,             0) /* 2.0 with modifications.         */
AGL_EXT(ARB_fragment_shader,           0) /*                                 */
AGL_EXT(ARB_shading_language_100,      0) /*                                 */
AGL_EXT(ARB_texture_non_power_of_two,2_0)
AGL_EXT(ARB_point_sprite,            2_0)
AGL_EXT(ARB_fragment_program_shadow,   0)
AGL_EXT(ARB_draw_buffers,            2_0)
AGL_EXT(ARB_texture_rectangle,       3_1)
AGL_EXT(ARB_color_buffer_float,      3_0)
AGL_EXT(ARB_half_float_pixel,        3_0)
AGL_EXT(ARB_texture_float,           3_0)
AGL_EXT(ARB_pixel_buffer_object,     2_1)
AGL_EXT(ARB_instanced_arrays,          0)
AGL_EXT(ARB_draw_instanced,          3_1)
AGL_EXT(ARB_geometry_shader4,          0)
AGL_EXT(ARB_texture_buffer_object,   3_1)
AGL_EXT(ARB_depth_buffer_float,      3_0)
AGL_EXT(ARB_framebuffer_object,      3_0)
AGL_EXT(ARB_framebuffer_sRGB,        3_0)
AGL_EXT(ARB_half_float_vertex,       3_0)
AGL_EXT(ARB_map_buffer_range,        3_0)
AGL_EXT(ARB_texture_compression_rgtc,3_0)
AGL_EXT(ARB_texture_rg,              3_0)
AGL_EXT(ARB_vertex_array_object,     3_0)
AGL_EXT(ARB_copy_buffer,             3_1)
AGL_EXT(ARB_compatibility,             0)
AGL_EXT(ARB_uniform_buffer_object,   3_1)
AGL_EXT(ARB_shader_texture_lod,        0)
AGL_EXT(ARB_depth_clamp,               3_2)
AGL_EXT(ARB_draw_elements_base_vertex, 3_2)
AGL_EXT(ARB_fragment_coord_conventions, 3_2)
AGL_EXT(ARB_provoking_vertex,          3_2)
AGL_EXT(ARB_seamless_cube_map,         3_2)
AGL_EXT(ARB_sync,                      3_2)
AGL_EXT(ARB_texture_multisample,       3_2)
AGL_EXT(ARB_vertex_array_bgra,         0)
AGL_EXT(ARB_draw_buffers_blend,        0)
AGL_EXT(ARB_sample_shading,            0)
AGL_EXT(ARB_texture_cube_map_array,    0)
AGL_EXT(ARB_texture_gather,            0)
AGL_EXT(ARB_texture_query_lod,         0)
AGL_EXT(ARB_shading_language_include,  0)
AGL_EXT(ARB_texture_compression_bptc,  0)
AGL_EXT(ARB_blend_func_extended,       3_3)
AGL_EXT(ARB_explicit_attrib_location,  3_3)
AGL_EXT(ARB_occlusion_query2,          3_3)
AGL_EXT(ARB_sampler_objects,           3_3)
AGL_EXT(ARB_shader_bit_encoding,       3_3)
AGL_EXT(ARB_texture_rgb10_a2ui,        3_3)
AGL_EXT(ARB_texture_swizzle,           3_3)
AGL_EXT(ARB_timer_query,               3_3)
AGL_EXT(ARB_vertex_type_2_10_10_10_rev, 3_3)
AGL_EXT(ARB_draw_indirect,             4_0)
AGL_EXT(ARB_gpu_shader5,               4_0)
AGL_EXT(ARB_gpu_shader_fp64,           4_0)
AGL_EXT(ARB_shader_subroutine,         4_0)
AGL_EXT(ARB_tessellation_shader,       4_0)
AGL_EXT(ARB_texture_buffer_object_rgb32, 4_0)
AGL_EXT(ARB_transform_feedback2,       4_0)
AGL_EXT(ARB_transform_feedback3,       4_0)

AGL_EXT(EXT_abgr,                      0)
AGL_EXT(EXT_blend_color,             1_1)
AGL_EXT(EXT_polygon_offset,          1_1)
AGL_EXT(EXT_texture,                 1_1)
AGL_EXT(EXT_texture3D,               1_2)
AGL_EXT(SGIS_texture_filter4,          0)
AGL_EXT(EXT_subtexture,              1_1)
AGL_EXT(EXT_copy_texture,            1_1)
AGL_EXT(EXT_histogram,                 0)
AGL_EXT(EXT_convolution,               0)
AGL_EXT(SGI_color_matrix,              0)
AGL_EXT(SGI_color_table,               0)
AGL_EXT(SGIS_pixel_texture,            0)
AGL_EXT(SGIX_pixel_texture,            0)
AGL_EXT(SGIS_texture4D,                0)
AGL_EXT(SGI_texture_color_table,       0)
AGL_EXT(EXT_cmyka,                     0)
AGL_EXT(EXT_texture_object,          1_1)
AGL_EXT(SGIS_detail_texture,           0)
AGL_EXT(SGIS_sharpen_texture,          0)
AGL_EXT(EXT_packed_pixels,           1_2)
AGL_EXT(SGIS_texture_lod,            1_2)
AGL_EXT(SGIS_multisample,            1_3)
AGL_EXT(EXT_rescale_normal,          1_2)
AGL_EXT(EXT_vertex_array,            1_1)
AGL_EXT(EXT_misc_attribute,            0)
AGL_EXT(SGIS_generate_mipmap,        1_4)
AGL_EXT(SGIX_clipmap,                  0)
AGL_EXT(SGIX_shadow,                   0)
AGL_EXT(SGIS_texture_edge_clamp,     1_2)
AGL_EXT(SGIS_texture_border_clamp,     0)
AGL_EXT(EXT_blend_minmax,              0)
AGL_EXT(EXT_blend_subtract,            0)
AGL_EXT(EXT_blend_logic_op,          1_1)
AGL_EXT(SGIX_interlace,                0)
AGL_EXT(SGIS_texture_select,           0)
AGL_EXT(SGIX_sprite,                   0)
AGL_EXT(SGIX_texture_multi_buffer,     0)
AGL_EXT(EXT_point_parameters,          0)
AGL_EXT(SGIX_instruments,              0)
AGL_EXT(SGIX_texture_scale_bias,       0)
AGL_EXT(SGIX_framezoom,                0)
AGL_EXT(SGIX_tag_sample_buffer,        0)
AGL_EXT(SGIX_reference_plane,          0)
AGL_EXT(SGIX_flush_raster,             0)
AGL_EXT(SGIX_depth_texture,            0)
AGL_EXT(SGIS_fog_function,             0)
AGL_EXT(SGIX_fog_offset,               0)
AGL_EXT(HP_image_transform,            0)
AGL_EXT(HP_convolution_border_modes,   0)
AGL_EXT(SGIX_texture_add_env,          0)
AGL_EXT(EXT_color_subtable,            0)
AGL_EXT(PGI_vertex_hints,              0)
AGL_EXT(PGI_misc_hints,                0)
AGL_EXT(EXT_paletted_texture,          0)
AGL_EXT(EXT_clip_volume_hint,          0)
AGL_EXT(SGIX_list_priority,            0)
AGL_EXT(SGIX_ir_instrument1,           0)
AGL_EXT(SGIX_texture_lod_bias,         0)
AGL_EXT(SGIX_shadow_ambient,           0)
AGL_EXT(EXT_index_texture,             0)
AGL_EXT(EXT_index_material,            0)
AGL_EXT(EXT_index_func,                0)
AGL_EXT(EXT_index_array_formats,       0)
AGL_EXT(EXT_compiled_vertex_array,     0)
AGL_EXT(EXT_cull_vertex,               0)
AGL_EXT(SGIX_ycrcb,                    0)
AGL_EXT(EXT_fragment_lighting,         0)
AGL_EXT(IBM_rasterpos_clip,            0)
AGL_EXT(HP_texture_lighting,           0)
AGL_EXT(EXT_draw_range_elements,       0)
AGL_EXT(WIN_phong_shading,             0)
AGL_EXT(WIN_specular_fog,              0)
AGL_EXT(EXT_light_texture,             0)
AGL_EXT(SGIX_blend_alpha_minmax,       0)
AGL_EXT(EXT_scene_marker,              0)
AGL_EXT(SGIX_pixel_texture_bits,       0)
AGL_EXT(EXT_bgra,                    1_2)
AGL_EXT(SGIX_async,                    0)
AGL_EXT(SGIX_async_pixel,              0)
AGL_EXT(SGIX_async_histogram,          0)
AGL_EXT(INTEL_texture_scissor,         0)
AGL_EXT(INTEL_parallel_arrays,         0)
AGL_EXT(HP_occlusion_test,             0)
AGL_EXT(EXT_pixel_transform,           0)
AGL_EXT(EXT_pixel_transform_color_table, 0)
AGL_EXT(EXT_shared_texture_palette,    0)
AGL_EXT(EXT_separate_specular_color, 1_2)
AGL_EXT(EXT_secondary_color,         1_4)
AGL_EXT(EXT_texture_env,               0)
AGL_EXT(EXT_texture_perturb_normal,    0)
AGL_EXT(EXT_multi_draw_arrays,       1_4)
AGL_EXT(EXT_fog_coord,               1_4)
AGL_EXT(REND_screen_coordinates,       0)
AGL_EXT(EXT_coordinate_frame,          0)
AGL_EXT(EXT_texture_env_combine,       0)
AGL_EXT(APPLE_specular_vector,         0)
AGL_EXT(APPLE_transform_hint,          0)
AGL_EXT(SUNX_constant_data,            0)
AGL_EXT(SUN_global_alpha,              0)
AGL_EXT(SUN_triangle_list,             0)
AGL_EXT(SUN_vertex,                    0)
AGL_EXT(EXT_blend_func_separate,     1_4)
AGL_EXT(INGR_color_clamp,              0)
AGL_EXT(INGR_interlace_read,           0)
AGL_EXT(EXT_stencil_wrap,            1_4)
AGL_EXT(EXT_422_pixels,                0)
AGL_EXT(NV_texgen_reflection,          0)
AGL_EXT(SGIX_texture_range,            0)
AGL_EXT(SUN_convolution_border_modes,  0)
AGL_EXT(EXT_texture_env_add,           0)
AGL_EXT(EXT_texture_lod_bias,        1_4)
AGL_EXT(EXT_texture_filter_anisotropic, 0)
AGL_EXT(EXT_vertex_weighting,          0)
AGL_EXT(NV_light_max_exponent,         0)
AGL_EXT(NV_vertex_array_range,         0)
AGL_EXT(NV_register_combiners,         0)
AGL_EXT(NV_fog_distance,               0)
AGL_EXT(NV_texgen_emboss,              0)
AGL_EXT(NV_blend_square,             1_4)
AGL_EXT(NV_texture_env_combine4,       0)
AGL_EXT(MESA_resize_buffers,           0)
AGL_EXT(MESA_window_pos,               0)
AGL_EXT(EXT_texture_compression_s3tc,  0)
AGL_EXT(IBM_cull_vertex,               0)
AGL_EXT(IBM_multimode_draw_arrays,     0)
AGL_EXT(IBM_vertex_array_lists,        0)
AGL_EXT(3DFX_texture_compression_FXT1, 0)
AGL_EXT(3DFX_multisample,              0)
AGL_EXT(3DFX_tbuffer,                  0)
AGL_EXT(SGIX_vertex_preclip,           0)
AGL_EXT(SGIX_resample,                 0)
AGL_EXT(SGIS_texture_color_mask,       0)
AGL_EXT(EXT_texture_env_dot3,          0)
AGL_EXT(ATI_texture_mirror_once,       0)
AGL_EXT(NV_fence,                      0)
AGL_EXT(IBM_static_data,               0)
AGL_EXT(IBM_texture_mirrored_repeat,   0)
AGL_EXT(NV_evaluators,                 0)
AGL_EXT(NV_packed_depth_stencil,     3_0)
AGL_EXT(NV_register_combiners2,        0)
AGL_EXT(NV_texture_compression_vtc,    0)
AGL_EXT(NV_texture_rectangle,          0)
AGL_EXT(NV_texture_shader,             0)
AGL_EXT(NV_texture_shader2,            0)
AGL_EXT(NV_vertex_array_range2,        0)
AGL_EXT(NV_vertex_program,             0)
AGL_EXT(SGIX_texture_coordinate_clamp, 0)
AGL_EXT(OML_interlace,                 0)
AGL_EXT(OML_subsample,                 0)
AGL_EXT(OML_resample,                  0)
AGL_EXT(NV_copy_depth_to_color,        0)
AGL_EXT(ATI_envmap_bumpmap,            0)
AGL_EXT(ATI_fragment_shader,           0)
AGL_EXT(ATI_pn_triangles,              0)
AGL_EXT(ATI_vertex_array_object,       0)
AGL_EXT(EXT_vertex_shader,             0)
AGL_EXT(ATI_vertex_streams,            0)
AGL_EXT(ATI_element_array,             0)
AGL_EXT(SUN_mesh_array,                0)
AGL_EXT(SUN_slice_accum,               0)
AGL_EXT(NV_multisample_filter_hint,    0)
AGL_EXT(NV_depth_clamp,                0)
AGL_EXT(NV_occlusion_query,            0)
AGL_EXT(NV_point_sprite,               0)
AGL_EXT(NV_texture_shader3,            0)
AGL_EXT(NV_vertex_program1_1,          0)
AGL_EXT(EXT_shadow_funcs,            1_5)
AGL_EXT(EXT_stencil_two_side,          0)
AGL_EXT(ATI_text_fragment_shader,      0)
AGL_EXT(APPLE_client_storage,          0)
AGL_EXT(APPLE_element_array,           0)
AGL_EXT(APPLE_fence,                   0)
AGL_EXT(APPLE_vertex_array_object,   3_0)
AGL_EXT(APPLE_vertex_array_range,      0)
AGL_EXT(APPLE_ycbcr_422,               0)
AGL_EXT(S3_s3tc,                       0)
AGL_EXT(ATI_draw_buffers,              0)
AGL_EXT(ATI_texture_env_combine3,      0)
AGL_EXT(ATI_texture_float,             0)
AGL_EXT(NV_float_buffer,               0)
AGL_EXT(NV_fragment_program,           0)
AGL_EXT(NV_half_float,               3_0)
AGL_EXT(NV_pixel_data_range,           0)
AGL_EXT(NV_primitive_restart,        3_1)
AGL_EXT(NV_texture_expand_normal,      0)
AGL_EXT(NV_vertex_program2,            0)
AGL_EXT(ATI_map_object_buffer,         0)
AGL_EXT(ATI_separate_stencil,        2_0)
AGL_EXT(ATI_vertex_attrib_array_object, 0)
AGL_EXT(OES_byte_coordinates,          0)
AGL_EXT(OES_fixed_point,               0)
AGL_EXT(OES_single_precision,          0)
AGL_EXT(OES_compressed_paletted_texture, 0)
AGL_EXT(OES_read_format,               0)
AGL_EXT(OES_query_matrix,              0)
AGL_EXT(OES_framebuffer_object,        0)
AGL_EXT(OES_texture_npot,              0)
AGL_EXT(EXT_depth_bounds_test,         0)
AGL_EXT(EXT_texture_mirror_clamp,      0)
AGL_EXT(EXT_blend_equation_separate,   0)
AGL_EXT(MESA_pack_invert,              0)
AGL_EXT(MESA_ycbcr_texture,            0)
AGL_EXT(EXT_pixel_buffer_object,       0)
AGL_EXT(NV_fragment_program_option,    0)
AGL_EXT(NV_fragment_program2,          0)
AGL_EXT(NV_vertex_program2_option,     0)
AGL_EXT(NV_vertex_program3,            0)
AGL_EXT(EXT_texture_compression_dxt1,  0)
AGL_EXT(EXT_framebuffer_object,      3_0)
AGL_EXT(GREMEDY_string_marker,         0)
AGL_EXT(EXT_packed_depth_stencil,      0)
AGL_EXT(EXT_stencil_clear_tag,         0)
AGL_EXT(EXT_texture_sRGB,            2_1)
AGL_EXT(EXT_framebuffer_blit,        3_0)
AGL_EXT(EXT_framebuffer_multisample, 3_0)
AGL_EXT(MESAX_texture_stack,           0)
AGL_EXT(EXT_timer_query,               0)
AGL_EXT(EXT_gpu_program_parameters,    0)
AGL_EXT(APPLE_flush_buffer_range,      0)
#ifdef ALLEGRO_MACOSX
AGL_EXT(EXT_texture_rectangle,         0)
#endif
AGL_EXT(EXT_bindable_uniform,          0)
AGL_EXT(EXT_draw_buffers2,           3_0)
AGL_EXT(EXT_draw_instanced,            0)
AGL_EXT(EXT_framebuffer_sRGB,        3_0)
AGL_EXT(EXT_geometry_shader4,          0)
AGL_EXT(EXT_gpu_shader4,             3_0)
AGL_EXT(EXT_packed_float,            3_0)
AGL_EXT(EXT_texture_array,           3_0)
AGL_EXT(EXT_texture_buffer_object,     0)
AGL_EXT(EXT_texture_compression_latc,  0)
AGL_EXT(EXT_texture_compression_rgtc,3_0)
AGL_EXT(EXT_texture_integer,         3_0)
AGL_EXT(EXT_texture_shared_exponent, 3_0)
AGL_EXT(NV_depth_buffer_float,       3_0)
AGL_EXT(NV_fragment_program4,          0)
AGL_EXT(NV_framebuffer_multisample_coverage, 0)
AGL_EXT(NV_geometry_program4,          0)
AGL_EXT(NV_gpu_program4,               0)
AGL_EXT(NV_parameter_buffer_object,    0)
AGL_EXT(NV_transform_feedback,         0)
AGL_EXT(NV_vertex_program4,            0)
AGL_EXT(GREMEDY_frame_terminator,      0)
AGL_EXT(NV_conditional_render,       3_0)
AGL_EXT(NV_present_video,              0)
AGL_EXT(EXT_direct_state_access,       0)
AGL_EXT(EXT_transform_feedback,      3_0)
AGL_EXT(EXT_texture_swizzle,           0)
AGL_EXT(NV_explicit_multisample,       0)
AGL_EXT(NV_transform_feedback2,        0)
AGL_EXT(ATI_meminfo,                   0)
AGL_EXT(AMD_performance_monitor,       0)
AGL_EXT(AMD_texture_texture4,          0)
AGL_EXT(AMD_vertex_shader_tesselator,  0)
AGL_EXT(EXT_provoking_vertex,          0)
AGL_EXT(EXT_texture_snorm,             0)
AGL_EXT(AMD_draw_buffers_blend,        0)
AGL_EXT(APPLE_texture_range,           0)
AGL_EXT(APPLE_float_pixels,            0)
AGL_EXT(APPLE_vertex_program_evaluators, 0)
AGL_EXT(APPLE_aux_depth_stencil,       0)
AGL_EXT(APPLE_object_purgeable,        0)
AGL_EXT(APPLE_row_bytes,               0)
AGL_EXT(APPLE_rgb_422,                 0)
AGL_EXT(NV_video_capture,              0)
AGL_EXT(EXT_separate_shader_objects,   0)
AGL_EXT(NV_parameter_buffer_object2,   0)
AGL_EXT(NV_shader_buffer_load,         0)
AGL_EXT(NV_vertex_buffer_unified_memory, 0)
AGL_EXT(NV_texture_barrier,            0)
AGL_EXT(AMD_shader_stencil_export,     0)
AGL_EXT(AMD_seamless_cubemap_per_texture, 0)
AGL_EXT(AMD_conservative_depth,        0)
